CA21_Cl01.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Video |
clickAndWait | link=Añadir vídeo |
type | id_name | nuevo
type | id_file | /home/fgil/Escritorio/merengue/selenium/test-data/test-video-flv.flv
clickAndWait | _save |
clickAndWait | link=nuevo |
clickAndWait | link=Borrar |
verifyTextPresent | exact:¿Está seguro? |
verifyTextPresent | exact:¿Está seguro de que quiere borrar los vídeo "nuevo"? Se borrarán los siguientes objetos relacionados: |
verifyTextPresent | Vídeo: nuevo |
clickAndWait | //input[@value='Sí, estoy seguro'] |
verifyTextPresent | Se eliminó con éxito el vídeo "nuevo". |
clickAndWait | link=Terminar sesión |